from .big_ass import big_ass
from .bitch_ass import bitch_ass
from .closed_ass import closed_ass
from .dumb_ass import dumb_ass
from .fuck import fuck
from .normal_ass import normal_ass
from .rich_ass import rich_ass
from .smart_ass import smart_ass
from .sybau import sybau
from .tight_ass import tight_ass
from .six_seven import six_seven

__version__ = "0.0.4"
__all__ = ["big_ass", "bitch_ass", "closed_ass", "dumb_ass", "fuck", "normal_ass", "rich_ass", "smart_ass", "sybau", "tight_ass", "six_seven"]


from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="POPA",
    author="EGOR",
    description="POPA MODULE",
    version="0.0.4",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    python_requires=" >= 3.6"
)